==> cook_2.19.orig.tar.gz: cook-2.19.orig/test/01/t0191a.sh <==
#!/bin/sh
#
#	cook - file construction tool
#	Copyright (C) 2000 Peter Miller;
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the c_incl functionality
#
work=/tmp/$$
PAGER=cat
export PAGER
umask 022
unset COOK
here=`pwd`
if test $? -ne 0 ; then exit 2; fi
SHELL=/bin/sh
export SHELL

bin="$here/${1-.}/bin"

pass()
{
	set +x
	cd $here
	rm -rf $work
	exit 0
}
fail()
{
	set +x
	echo 'FAILED test of the c_incl functionality' 1>&2
	cd $here
	rm -rf $work
	exit 1
}
no_result()
{
	set +x
	echo 'NO RESULT for test of the c_incl functionality' 1>&2
	cd $here
	rm -rf $work
	exit 2
}
trap \"no_result\" 1 2 3 15


mkdir $work $work/lib
if test $? -ne 0 ; then no_result; fi
cd $work
if test $? -ne 0 ; then no_result; fi

#
# Use the default error messages.  There is no other way to get
# predictable test behaviour on the unknown systems we will be tested on.
#
COOK_MESSAGE_LIBRARY=$work/no-such-dir
export COOK_MESSAGE_LIBRARY
unset LANG
unset LANGUAGE

#
# test the c_incl functionality
#

mkdir include prog prog/include prog/prog

cat > prog/prog/main.c << 'fubar'
#include <first.h>
#include <second.h>
void main(){}
fubar
if test $? -ne 0 ; then no_result; fi

cat > include/first.h << 'fubar'
#define FIRST
fubar
if test $? -ne 0 ; then no_result; fi

cat > prog/include/second.h << 'fubar'
#define SECOND
fubar
if test $? -ne 0 ; then no_result; fi

cat > test.ok << fubar
$work/include/first.h
$work/prog/include/second.h
fubar
if test $? -ne 0 ; then no_result; fi

( cd prog/prog && $bin/c_incl -nc -alm -I ${work}/prog/include -I ${work}/include main.c -o test.out )
if test $? -ne 0 ; then fail; fi

diff test.ok prog/prog/test.out
if test $? -ne 0 ; then fail; fi

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass

==> cook_2.26.orig.tar.gz: cook-2.26/test/01/t0191a.sh <==
#!/bin/sh
#
#	cook - file construction tool
#	Copyright (C) 2000, 2002 Peter Miller;
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the c_incl functionality
#
work=/tmp/$$
PAGER=cat
export PAGER
umask 022
unset COOK
here=`pwd`
if test $? -ne 0 ; then exit 2; fi
SHELL=/bin/sh
export SHELL

bin="$here/${1-.}/bin"

pass()
{
	set +x
	cd $here
	rm -rf $work
	exit 0
}
fail()
{
	set +x
	echo 'FAILED test of the c_incl functionality' 1>&2
	cd $here
	rm -rf $work
	exit 1
}
no_result()
{
	set +x
	echo 'NO RESULT for test of the c_incl functionality' 1>&2
	cd $here
	rm -rf $work
	exit 2
}
trap \"no_result\" 1 2 3 15


mkdir $work $work/lib
if test $? -ne 0 ; then no_result; fi
cd $work
if test $? -ne 0 ; then no_result; fi

#
# Use the default error messages.  There is no other way to get
# predictable test behaviour on the unknown systems we will be tested on.
#
COOK_MESSAGE_LIBRARY=$work/no-such-dir
export COOK_MESSAGE_LIBRARY
unset LANG
unset LANGUAGE

#
# test the c_incl functionality
#

mkdir include prog prog/include prog/prog

cat > prog/prog/main.c << 'fubar'
#include <first.h>
#include <second.h>
void main(){}
fubar
if test $? -ne 0 ; then no_result; fi

cat > include/first.h << 'fubar'
#define FIRST
fubar
if test $? -ne 0 ; then no_result; fi

cat > prog/include/second.h << 'fubar'
#define SECOND
fubar
if test $? -ne 0 ; then no_result; fi

cat > test.ok << fubar
$work/include/first.h
$work/prog/include/second.h
fubar
if test $? -ne 0 ; then no_result; fi

( cd prog/prog && \
	$bin/c_incl -nc -alm -I ${work}/prog/include -I ${work}/include \
	main.c -o test.out )
if test $? -ne 0 ; then fail; fi

diff test.ok prog/prog/test.out
if test $? -ne 0 ; then fail; fi

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass
